Crate repo_path_macro

Crate repo_path_macro 

Macros for the repo_path crate.

Macros

custom_base_path
Construct a std::path::PathBuf for static paths in your repository with a custom base path. This macro is intended for use in custom_base_path_macro!().
repo_include_str
Include the contents of a file in your repository as a string into the source code.
repo_path
Easily construct a std::path::PathBuf for static paths in your repository.