Macros for the repo_path crate.
Macros
- custom_
base_ path - Construct a std::path::PathBuf for static paths in your repository with a custom base path.
This macro is intended for use in
custom_base_path_macro!(). - repo_
include_ str - Include the contents of a file in your repository as a string into the source code.
- repo_
path - Easily construct a std::path::PathBuf for static paths in your repository.